
From: Pekka Enberg <penberg@cs.helsinki.fi>

This patch converts kcalloc(1, ...) calls to use the new kzalloc() function.

Signed-off-by: Pekka Enberg <penberg@cs.helsinki.fi>
Cc: Greg KH <greg@kroah.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/usb/atm/usbatm.c       |    2 +-
 drivers/usb/core/hcd.c         |    2 +-
 drivers/usb/host/ehci-sched.c  |    2 +-
 drivers/usb/host/isp116x-hcd.c |    2 +-
 drivers/usb/host/sl811-hcd.c   |    2 +-
 drivers/usb/input/acecad.c     |    2 +-
 drivers/usb/input/itmtouch.c   |    2 +-
 drivers/usb/input/pid.c        |    2 +-
 8 files changed, 8 insertions(+), 8 deletions(-)

diff -puN drivers/usb/atm/usbatm.c~usb-convert-kcalloc-to-kzalloc drivers/usb/atm/usbatm.c
--- devel/drivers/usb/atm/usbatm.c~usb-convert-kcalloc-to-kzalloc	2005-08-21 23:48:39.000000000 -0700
+++ devel-akpm/drivers/usb/atm/usbatm.c	2005-08-21 23:48:39.000000000 -0700
@@ -960,7 +960,7 @@ int usbatm_usb_probe(struct usb_interfac
 			intf->altsetting->desc.bInterfaceNumber);
 
 	/* instance init */
-	instance = kcalloc(1, sizeof(*instance) + sizeof(struct urb *) * (num_rcv_urbs + num_snd_urbs), GFP_KERNEL);
+	instance = kzalloc(sizeof(*instance) + sizeof(struct urb *) * (num_rcv_urbs + num_snd_urbs), GFP_KERNEL);
 	if (!instance) {
 		dev_dbg(dev, "%s: no memory for instance data!\n", __func__);
 		return -ENOMEM;
diff -puN drivers/usb/core/hcd.c~usb-convert-kcalloc-to-kzalloc drivers/usb/core/hcd.c
--- devel/drivers/usb/core/hcd.c~usb-convert-kcalloc-to-kzalloc	2005-08-21 23:48:39.000000000 -0700
+++ devel-akpm/drivers/usb/core/hcd.c	2005-08-21 23:48:39.000000000 -0700
@@ -1669,7 +1669,7 @@ struct usb_hcd *usb_create_hcd (const st
 {
 	struct usb_hcd *hcd;
 
-	hcd = kcalloc(1, sizeof(*hcd) + driver->hcd_priv_size, GFP_KERNEL);
+	hcd = kzalloc(sizeof(*hcd) + driver->hcd_priv_size, GFP_KERNEL);
 	if (!hcd) {
 		dev_dbg (dev, "hcd alloc failed\n");
 		return NULL;
diff -puN drivers/usb/host/ehci-sched.c~usb-convert-kcalloc-to-kzalloc drivers/usb/host/ehci-sched.c
--- devel/drivers/usb/host/ehci-sched.c~usb-convert-kcalloc-to-kzalloc	2005-08-21 23:48:39.000000000 -0700
+++ devel-akpm/drivers/usb/host/ehci-sched.c	2005-08-21 23:48:39.000000000 -0700
@@ -638,7 +638,7 @@ iso_stream_alloc (unsigned mem_flags)
 {
 	struct ehci_iso_stream *stream;
 
-	stream = kcalloc(1, sizeof *stream, mem_flags);
+	stream = kzalloc(sizeof *stream, mem_flags);
 	if (likely (stream != NULL)) {
 		INIT_LIST_HEAD(&stream->td_list);
 		INIT_LIST_HEAD(&stream->free_list);
diff -puN drivers/usb/host/isp116x-hcd.c~usb-convert-kcalloc-to-kzalloc drivers/usb/host/isp116x-hcd.c
--- devel/drivers/usb/host/isp116x-hcd.c~usb-convert-kcalloc-to-kzalloc	2005-08-21 23:48:39.000000000 -0700
+++ devel-akpm/drivers/usb/host/isp116x-hcd.c	2005-08-21 23:48:39.000000000 -0700
@@ -715,7 +715,7 @@ static int isp116x_urb_enqueue(struct us
 	}
 	/* avoid all allocations within spinlocks: request or endpoint */
 	if (!hep->hcpriv) {
-		ep = kcalloc(1, sizeof *ep, mem_flags);
+		ep = kzalloc(sizeof *ep, mem_flags);
 		if (!ep)
 			return -ENOMEM;
 	}
diff -puN drivers/usb/host/sl811-hcd.c~usb-convert-kcalloc-to-kzalloc drivers/usb/host/sl811-hcd.c
--- devel/drivers/usb/host/sl811-hcd.c~usb-convert-kcalloc-to-kzalloc	2005-08-21 23:48:39.000000000 -0700
+++ devel-akpm/drivers/usb/host/sl811-hcd.c	2005-08-21 23:48:39.000000000 -0700
@@ -835,7 +835,7 @@ static int sl811h_urb_enqueue(
 
 	/* avoid all allocations within spinlocks */
 	if (!hep->hcpriv)
-		ep = kcalloc(1, sizeof *ep, mem_flags);
+		ep = kzalloc(sizeof *ep, mem_flags);
 
 	spin_lock_irqsave(&sl811->lock, flags);
 
diff -puN drivers/usb/input/acecad.c~usb-convert-kcalloc-to-kzalloc drivers/usb/input/acecad.c
--- devel/drivers/usb/input/acecad.c~usb-convert-kcalloc-to-kzalloc	2005-08-21 23:48:39.000000000 -0700
+++ devel-akpm/drivers/usb/input/acecad.c	2005-08-21 23:48:39.000000000 -0700
@@ -152,7 +152,7 @@ static int usb_acecad_probe(struct usb_i
 	pipe = usb_rcvintpipe(dev, endpoint->bEndpointAddress);
 	maxp = usb_maxpacket(dev, pipe, usb_pipeout(pipe));
 
-	acecad = kcalloc(1, sizeof(struct usb_acecad), GFP_KERNEL);
+	acecad = kzalloc(sizeof(struct usb_acecad), GFP_KERNEL);
 	if (!acecad)
 		return -ENOMEM;
 
diff -puN drivers/usb/input/itmtouch.c~usb-convert-kcalloc-to-kzalloc drivers/usb/input/itmtouch.c
--- devel/drivers/usb/input/itmtouch.c~usb-convert-kcalloc-to-kzalloc	2005-08-21 23:48:39.000000000 -0700
+++ devel-akpm/drivers/usb/input/itmtouch.c	2005-08-21 23:48:39.000000000 -0700
@@ -166,7 +166,7 @@ static int itmtouch_probe(struct usb_int
 	interface = intf->cur_altsetting;
 	endpoint = &interface->endpoint[0].desc;
 
-	if (!(itmtouch = kcalloc(1, sizeof(struct itmtouch_dev), GFP_KERNEL))) {
+	if (!(itmtouch = kzalloc(sizeof(struct itmtouch_dev), GFP_KERNEL))) {
 		err("%s - Out of memory.", __FUNCTION__);
 		return -ENOMEM;
 	}
diff -puN drivers/usb/input/pid.c~usb-convert-kcalloc-to-kzalloc drivers/usb/input/pid.c
--- devel/drivers/usb/input/pid.c~usb-convert-kcalloc-to-kzalloc	2005-08-21 23:48:39.000000000 -0700
+++ devel-akpm/drivers/usb/input/pid.c	2005-08-21 23:48:39.000000000 -0700
@@ -263,7 +263,7 @@ int hid_pid_init(struct hid_device *hid)
 	struct hid_ff_pid *private;
 	struct hid_input *hidinput = list_entry(&hid->inputs, struct hid_input, list);
 
-	private = hid->ff_private = kcalloc(1, sizeof(struct hid_ff_pid), GFP_KERNEL);
+	private = hid->ff_private = kzalloc(sizeof(struct hid_ff_pid), GFP_KERNEL);
 	if (!private)
 		return -ENOMEM;
 
_
